@@ -2,16 +2,16 @@ package App::Goto;
 
 use strict;
 use v5.12;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Moo;
 
 has args        => ( is => 'ro', required => 1 );
 has config      => ( is => 'ro', required => 1 );
 has error       => ( is => 'rw', default => sub { 'Unknown error' } );
-has is_success  => ( is => 'rw', default => 1 );
+has is_success  => ( is => 'rw', default => sub { 1 } );
 has cmd         => ( is => 'rw' );
-has name        => ( is => 'rw', default => '' );
+has name        => ( is => 'rw', default => sub { '' } );
 
 sub BUILD {
     my $self = shift;
